pub fn format_metric_with_statistic(
metric: Metric,
statistic: MetricStatistic,
) -> StringExpand description
Format a metric key, appending the statistic name when it is not the default (median).
pub fn format_metric_with_statistic(
metric: Metric,
statistic: MetricStatistic,
) -> StringFormat a metric key, appending the statistic name when it is not the default (median).